# Generated by Django 4.0.3 on 2022-04-05 14:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('EmailTemplate', '0004_auto_20210226_0911'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailtemplate',
            name='bcc',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='BCC'),
        ),
        migrations.AddField(
            model_name='emailtemplate',
            name='cc',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='CC'),
        ),
    ]



# Generated by Django 3.1.6 on 2021-02-26 09:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('EmailTemplate', '0003_auto_20190719_1358'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='to_email',
            field=models.CharField(blank=True, max_length=1000, null=True, verbose_name='To'),
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-19 13:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('EmailTemplate', '0002_auto_20190719_1354'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='subject',
            field=models.CharField(default='CHANGE ME', max_length=255, verbose_name='Subject'),
            preserve_default=False,
        ),
    ]



# Generated by Django 2.1.3 on 2019-01-10 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('template_key', models.CharField(max_length=255, unique=True, verbose_name='Key')),
                ('subject', models.CharField(blank=True, max_length=255, null=True, verbose_name='Subject')),
                ('to_email', models.CharField(blank=True, max_length=255, null=True, verbose_name='To')),
                ('from_email', models.CharField(blank=True, max_length=255, null=True, verbose_name='From')),
                ('html_template', models.TextField(blank=True, null=True, verbose_name='HTML')),
                ('plain_text', models.TextField(blank=True, null=True, verbose_name='Plain')),
                ('is_html', models.BooleanField(default=False, verbose_name='Is HTML?')),
                ('is_text', models.BooleanField(default=False, verbose_name='Is Text?')),
            ],
        ),
    ]



from django.test import TestCase
from django.test import Client
from .models import EmailTemplate

# Create your tests here.
#python manage.py dumpdata EmailTemplate > data.json 

class EmailTest(TestCase):
    fixtures = ['data.json',]

    def setUp(self):
        self.client = Client()

    def test_multiple_addresses(self):
        print('aa')
        context={}
        context['user']='test_user'
        EmailTemplate.send('TEST', context,)